@@ -1,19 +1,19 @@
 # -*- coding: utf-8 -*-
-#    Copyright (C) 2012  Christian Ledermann
+# Copyright (C) 2012  Christian Ledermann
 #
-#    This library is free software; you can redistribute it and/or
-#    modify it under the terms of the GNU Lesser General Public
-#    License as published by the Free Software Foundation; either
-#    version 2.1 of the License, or (at your option) any later version.
+# This library is free software; you can redistribute it and/or
+# modify it under the terms of the GNU Lesser General Public
+# License as published by the Free Software Foundation; either
+# version 2.1 of the License, or (at your option) any later version.
 #
-#    This library is distributed in the hope that it will be useful,
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-#    Lesser General Public License for more details.
+# This library is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+# Lesser General Public License for more details.
 #
-#    You should have received a copy of the GNU Lesser General Public
-#    License along with this library; if not, write to the Free Software
-#    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+# You should have received a copy of the GNU Lesser General Public
+# License along with this library; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
 """
 Once you've created features within Google Earth and examined the KML
 code Google Earth generates, you'll notice how styles are an important
@@ -23,13 +23,10 @@ part of how your data is displayed.
 import logging
 logger = logging.getLogger('fastkml.styles')
 
-import fastkml.config as config
 from fastkml.config import etree
 from fastkml.base import _BaseObject
 
 
-
-
 class StyleUrl(_BaseObject):
     """
     URL of a <Style> or <StyleMap> defined in a Document. If the style
@@ -78,7 +75,7 @@ class Style(_StyleSelector):
     __name__ = "Style"
     _styles = None
 
-    def __init__(self, ns=None, id=None, styles = None):
+    def __init__(self, ns=None, id=None, styles=None):
         super(Style, self).__init__(ns, id)
         self._styles = []
         if styles:
@@ -100,27 +97,27 @@ class Style(_StyleSelector):
 
     def from_element(self, element):
         super(Style, self).from_element(element)
-        style = element.find('%sIconStyle' %self.ns)
+        style = element.find('%sIconStyle' % self.ns)
         if style is not None:
             thestyle = IconStyle(self.ns)
             thestyle.from_element(style)
             self.append_style(thestyle)
-        style = element.find('%sLineStyle' %self.ns)
+        style = element.find('%sLineStyle' % self.ns)
         if style is not None:
             thestyle = LineStyle(self.ns)
             thestyle.from_element(style)
             self.append_style(thestyle)
-        style = element.find('%sPolyStyle' %self.ns)
+        style = element.find('%sPolyStyle' % self.ns)
         if style is not None:
             thestyle = PolyStyle(self.ns)
             thestyle.from_element(style)
             self.append_style(thestyle)
-        style = element.find('%sLabelStyle' %self.ns)
+        style = element.find('%sLabelStyle' % self.ns)
         if style is not None:
             thestyle = LabelStyle(self.ns)
             thestyle.from_element(style)
             self.append_style(thestyle)
-        style = element.find('%sBalloonStyle' %self.ns)
+        style = element.find('%sBalloonStyle' % self.ns)
         if style is not None:
             thestyle = BalloonStyle(self.ns)
             thestyle.from_element(style)
@@ -148,14 +145,13 @@ class StyleMap(_StyleSelector):
         super(StyleMap, self).__init__(ns, id)
         pass
 
-
     def from_element(self, element):
         super(StyleMap, self).from_element(element)
-        pairs = element.findall('%sPair' %self.ns)
+        pairs = element.findall('%sPair' % self.ns)
         for pair in pairs:
-            key = pair.find('%skey' %self.ns)
-            style = pair.find('%sStyle' %self.ns)
-            style_url = pair.find('%sstyleUrl' %self.ns)
+            key = pair.find('%skey' % self.ns)
+            style = pair.find('%sStyle' % self.ns)
+            style_url = pair.find('%sstyleUrl' % self.ns)
             if key.text == "highlight":
                 if style is not None:
                     highlight = Style(self.ns)
@@ -179,20 +175,18 @@ class StyleMap(_StyleSelector):
             else:
                 raise ValueError
 
-
-
     def etree_element(self):
         element = super(StyleMap, self).etree_element()
         if self.normal:
             if isinstance(self.normal, (Style, StyleUrl)):
-                pair = etree.SubElement(element, "%sPair" %self.ns)
-                key = etree.SubElement(pair, "%skey" %self.ns)
+                pair = etree.SubElement(element, "%sPair" % self.ns)
+                key = etree.SubElement(pair, "%skey" % self.ns)
                 key.text = 'normal'
                 pair.append(self.normal.etree_element())
         if self.highlight:
             if isinstance(self.highlight, (Style, StyleUrl)):
-                pair = etree.SubElement(element, "%sPair" %self.ns)
-                key = etree.SubElement(pair, "%skey" %self.ns)
+                pair = etree.SubElement(element, "%sPair" % self.ns)
+                key = etree.SubElement(pair, "%skey" % self.ns)
                 key.text = 'highlight'
                 pair.append(self.highlight.etree_element())
         return element
@@ -224,27 +218,26 @@ class _ColorStyle(_BaseObject):
         self.color = color
         self.colorMode = colorMode
 
-
     def etree_element(self):
         element = super(_ColorStyle, self).etree_element()
         if self.color:
-            color = etree.SubElement(element, "%scolor" %self.ns)
+            color = etree.SubElement(element, "%scolor" % self.ns)
             color.text = self.color
         if self.colorMode:
-            colorMode = etree.SubElement(element, "%scolorMode" %self.ns)
+            colorMode = etree.SubElement(element, "%scolorMode" % self.ns)
             colorMode.text = self.colorMode
         return element
 
-
     def from_element(self, element):
         super(_ColorStyle, self).from_element(element)
-        colorMode = element.find('%scolorMode' %self.ns)
+        colorMode = element.find('%scolorMode' % self.ns)
         if colorMode is not None:
             self.colorMode = colorMode.text
-        color = element.find('%scolor' %self.ns)
+        color = element.find('%scolor' % self.ns)
         if color is not None:
             self.color = color.text
 
+
 class IconStyle(_ColorStyle):
     """ Specifies how icons for point Placemarks are drawn """
     __name__ = "IconStyle"
@@ -256,8 +249,10 @@ class IconStyle(_ColorStyle):
     icon_href = None
     # An HTTP address or a local file specification used to load an icon.
 
-    def __init__(self, ns=None, id=None, color=None, colorMode=None,
-                scale=1.0, heading=None, icon_href=None):
+    def __init__(
+        self, ns=None, id=None, color=None, colorMode=None, scale=1.0,
+        heading=None, icon_href=None
+    ):
         super(IconStyle, self).__init__(ns, id, color, colorMode)
         self.scale = scale
         self.heading = heading
@@ -266,33 +261,32 @@ class IconStyle(_ColorStyle):
     def etree_element(self):
         element = super(IconStyle, self).etree_element()
         if self.scale is not None:
-            scale = etree.SubElement(element, "%sscale" %self.ns)
+            scale = etree.SubElement(element, "%sscale" % self.ns)
             scale.text = str(self.scale)
         if self.heading:
-            heading = etree.SubElement(element, "%sheading" %self.ns)
+            heading = etree.SubElement(element, "%sheading" % self.ns)
             heading.text = str(self.heading)
         if self.icon_href:
-            icon = etree.SubElement(element, "%sIcon" %self.ns)
-            href = etree.SubElement(icon, "%shref" %self.ns)
+            icon = etree.SubElement(element, "%sIcon" % self.ns)
+            href = etree.SubElement(icon, "%shref" % self.ns)
             href.text = self.icon_href
         return element
 
     def from_element(self, element):
         super(IconStyle, self).from_element(element)
-        scale = element.find('%sscale' %self.ns)
+        scale = element.find('%sscale' % self.ns)
         if scale is not None:
             self.scale = float(scale.text)
-        heading = element.find('%sheading' %self.ns)
+        heading = element.find('%sheading' % self.ns)
         if heading is not None:
             self.heading = float(heading.text)
-        icon = element.find('%sIcon' %self.ns)
+        icon = element.find('%sIcon' % self.ns)
         if icon is not None:
-            href = icon.find('%shref' %self.ns)
+            href = icon.find('%shref' % self.ns)
             if href is not None:
                 self.icon_href = href.text
 
 
-
 class LineStyle(_ColorStyle):
     """
     Specifies the drawing style (color, color mode, and line width)
@@ -304,24 +298,26 @@ class LineStyle(_ColorStyle):
     width = 1.0
     # Width of the line, in pixels.
 
-    def __init__(self, ns=None, id=None, color=None, colorMode=None,
-                width=1):
+    def __init__(
+        self, ns=None, id=None, color=None, colorMode=None, width=1
+    ):
         super(LineStyle, self).__init__(ns, id, color, colorMode)
         self.width = width
 
     def etree_element(self):
         element = super(LineStyle, self).etree_element()
         if self.width is not None:
-            width = etree.SubElement(element, "%swidth" %self.ns)
+            width = etree.SubElement(element, "%swidth" % self.ns)
             width.text = str(self.width)
         return element
 
     def from_element(self, element):
         super(LineStyle, self).from_element(element)
-        width = element.find('%swidth' %self.ns)
+        width = element.find('%swidth' % self.ns)
         if width is not None:
             self.width = float(width.text)
 
+
 class PolyStyle(_ColorStyle):
     """
     Specifies the drawing style for all polygons, including polygon
@@ -335,8 +331,9 @@ class PolyStyle(_ColorStyle):
     # Boolean value. Specifies whether to outline the polygon.
     # Polygon outlines use the current LineStyle.
 
-    def __init__(self, ns=None, id=None, color=None, colorMode=None,
-                fill=1, outline=1):
+    def __init__(
+        self, ns=None, id=None, color=None, colorMode=None, fill=1, outline=1
+    ):
         super(PolyStyle, self).__init__(ns, id, color, colorMode)
         self.fill = fill
         self.outline = outline
@@ -344,19 +341,19 @@ class PolyStyle(_ColorStyle):
     def etree_element(self):
         element = super(PolyStyle, self).etree_element()
         if self.fill is not None:
-            fill = etree.SubElement(element, "%sfill" %self.ns)
+            fill = etree.SubElement(element, "%sfill" % self.ns)
             fill.text = str(self.fill)
         if self.outline is not None:
-            outline = etree.SubElement(element, "%soutline" %self.ns)
+            outline = etree.SubElement(element, "%soutline" % self.ns)
             outline.text = str(self.outline)
         return element
 
     def from_element(self, element):
         super(PolyStyle, self).from_element(element)
-        fill = element.find('%sfill' %self.ns)
+        fill = element.find('%sfill' % self.ns)
         if fill is not None:
             self.fill = int(fill.text)
-        outline = element.find('%soutline' %self.ns)
+        outline = element.find('%soutline' % self.ns)
         if outline is not None:
             self.outline = int(outline.text)
 
@@ -369,24 +366,26 @@ class LabelStyle(_ColorStyle):
     scale = 1.0
     # Resizes the label.
 
-    def __init__(self, ns=None, id=None, color=None, colorMode=None,
-                scale=1.0):
+    def __init__(
+        self, ns=None, id=None, color=None, colorMode=None, scale=1.0
+    ):
         super(LabelStyle, self).__init__(ns, id, color, colorMode)
         self.scale = scale
 
     def etree_element(self):
         element = super(LabelStyle, self).etree_element()
         if self.scale is not None:
-            scale = etree.SubElement(element, "%sscale" %self.ns)
+            scale = etree.SubElement(element, "%sscale" % self.ns)
             scale.text = str(self.scale)
         return element
 
     def from_element(self, element):
         super(LabelStyle, self).from_element(element)
-        scale = element.find('%sscale' %self.ns)
+        scale = element.find('%sscale' % self.ns)
         if scale is not None:
             self.scale = float(scale.text)
 
+
 class BalloonStyle(_BaseObject):
     """ Specifies how the description balloon for placemarks is drawn.
         The <bgColor>, if specified, is used as the background color of
@@ -395,15 +394,15 @@ class BalloonStyle(_BaseObject):
     __name__ = "BalloonStyle"
 
     bgColor = None
-    #Background color of the balloon (optional). Color and opacity (alpha)
-    #values are expressed in hexadecimal notation. The range of values for
-    #any one color is 0 to 255 (00 to ff). The order of expression is
+    # Background color of the balloon (optional). Color and opacity (alpha)
+    # values are expressed in hexadecimal notation. The range of values for
+    # any one color is 0 to 255 (00 to ff). The order of expression is
     # aabbggrr, where aa=alpha (00 to ff); bb=blue (00 to ff);
     # gg=green (00 to ff); rr=red (00 to ff).
     # For alpha, 00 is fully transparent and ff is fully opaque.
     # For example, if you want to apply a blue color with 50 percent
     # opacity to an overlay, you would specify the following:
-    #<bgColor>7fff0000</bgColor>, where alpha=0x7f, blue=0xff, green=0x00,
+    # <bgColor>7fff0000</bgColor>, where alpha=0x7f, blue=0xff, green=0x00,
     # and red=0x00. The default is opaque white (ffffffff).
     # Note: The use of the <color> element within <BalloonStyle> has been
     # deprecated. Use <bgColor> instead.
@@ -412,33 +411,36 @@ class BalloonStyle(_BaseObject):
     # Foreground color for text. The default is black (ff000000).
 
     text = None
-    #Text displayed in the balloon. If no text is specified, Google Earth
-    #draws the default balloon (with the Feature <name> in boldface,
-    #the Feature <description>, links for driving directions, a white
-    #background, and a tail that is attached to the point coordinates of
-    #the Feature, if specified).
-    #You can add entities to the <text> tag using the following format to
-    #refer to a child element of Feature: $[name], $[description], $[address],
-    #$[id], $[Snippet]. Google Earth looks in the current Feature for the
-    #corresponding string entity and substitutes that information in the balloon.
-    #To include To here - From here driving directions in the balloon,
-    #use the $[geDirections] tag. To prevent the driving directions links
-    #from appearing in a balloon, include the <text> element with some content,
-    #or with $[description] to substitute the basic Feature <description>.
-    #For example, in the following KML excerpt, $[name] and $[description]
-    #fields will be replaced by the <name> and <description> fields found
-    #in the Feature elements that use this BalloonStyle:
-    #<text>This is $[name], whose description is:<br/>$[description]</text>
+    # Text displayed in the balloon. If no text is specified, Google Earth
+    # draws the default balloon (with the Feature <name> in boldface,
+    # the Feature <description>, links for driving directions, a white
+    # background, and a tail that is attached to the point coordinates of
+    # the Feature, if specified).
+    # You can add entities to the <text> tag using the following format to
+    # refer to a child element of Feature: $[name], $[description], $[address],
+    # $[id], $[Snippet]. Google Earth looks in the current Feature for the
+    # corresponding string entity and substitutes that information in the
+    # balloon.
+    # To include To here - From here driving directions in the balloon,
+    # use the $[geDirections] tag. To prevent the driving directions links
+    # from appearing in a balloon, include the <text> element with some content
+    # or with $[description] to substitute the basic Feature <description>.
+    # For example, in the following KML excerpt, $[name] and $[description]
+    # fields will be replaced by the <name> and <description> fields found
+    # in the Feature elements that use this BalloonStyle:
+    # <text>This is $[name], whose description is:<br/>$[description]</text>
 
     displayMode = None
-    #If <displayMode> is default, Google Earth uses the information supplied
-    #in <text> to create a balloon . If <displayMode> is hide, Google Earth
-    #does not display the balloon. In Google Earth, clicking the List View
-    #icon for a Placemark whose balloon's <displayMode> is hide causes
-    #Google Earth to fly to the Placemark.
+    # If <displayMode> is default, Google Earth uses the information supplied
+    # in <text> to create a balloon . If <displayMode> is hide, Google Earth
+    # does not display the balloon. In Google Earth, clicking the List View
+    # icon for a Placemark whose balloon's <displayMode> is hide causes
+    # Google Earth to fly to the Placemark.
 
-    def __init__(self, ns=None, id=None, bgColor=None, textColor=None,
-                text=None, displayMode=None):
+    def __init__(
+        self, ns=None, id=None, bgColor=None, textColor=None, text=None,
+        displayMode=None
+    ):
         super(BalloonStyle, self).__init__(ns, id)
         self.bgColor = bgColor
         self.textColor = textColor
@@ -447,35 +449,35 @@ class BalloonStyle(_BaseObject):
 
     def from_element(self, element):
         super(BalloonStyle, self).from_element(element)
-        bgColor = element.find('%sbgColor' %self.ns)
+        bgColor = element.find('%sbgColor' % self.ns)
         if bgColor is not None:
             self.bgColor = bgColor.text
         else:
-            bgColor = element.find('%scolor' %self.ns)
+            bgColor = element.find('%scolor' % self.ns)
             if bgColor is not None:
                 self.bgColor = bgColor.text
-        textColor = element.find('%stextColor' %self.ns)
+        textColor = element.find('%stextColor' % self.ns)
         if textColor is not None:
             self.textColor = textColor.text
-        text = element.find('%stext' %self.ns)
+        text = element.find('%stext' % self.ns)
         if text is not None:
             self.text = text.text
-        displayMode = element.find('%sdisplayMode' %self.ns)
+        displayMode = element.find('%sdisplayMode' % self.ns)
         if displayMode is not None:
             self.displayMode = displayMode.text
 
     def etree_element(self):
         element = super(BalloonStyle, self).etree_element()
         if self.bgColor is not None:
-            elem = etree.SubElement(element, "%sbgColor" %self.ns)
+            elem = etree.SubElement(element, "%sbgColor" % self.ns)
             elem.text = self.bgColor
         if self.textColor is not None:
-            elem = etree.SubElement(element, "%stextColor" %self.ns)
+            elem = etree.SubElement(element, "%stextColor" % self.ns)
             elem.text = self.textColor
         if self.text is not None:
-            elem = etree.SubElement(element, "%stext" %self.ns)
+            elem = etree.SubElement(element, "%stext" % self.ns)
             elem.text = self.text
         if self.displayMode is not None:
-            elem = etree.SubElement(element, "%sdisplayMode" %self.ns)
+            elem = etree.SubElement(element, "%sdisplayMode" % self.ns)
             elem.text = self.displayMode
         return element
